==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Brands/CreativeCommonsSampling.md <==
# CreativeCommonsSampling


```text
fontawesome-6/Brands/CreativeCommonsSampling
```

```text
include('fontawesome-6/Brands/CreativeCommonsSampling')
```



| Illustration | CreativeCommonsSampling |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Brands/CreativeCommonsSampling.png) | ![illustration for CreativeCommonsSampling](../../fontawesome-6/Brands/CreativeCommonsSampling.Local.png) |




## CreativeCommonsSampling

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element CreativeCommonsSampling
include('fontawesome-6/Brands/CreativeCommonsSampling')

' renders the element
CreativeCommonsSampling('CreativeCommonsSampling', 'Creative Commons Sampling', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element CreativeCommonsSampling
include('fontawesome-6/Brands/CreativeCommonsSampling')

' renders the element
CreativeCommonsSampling('CreativeCommonsSampling', 'Creative Commons Sampling', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Brands/CreativeCommonsSampling.md <==
# CreativeCommonsSampling


```text
fontawesome-6/Brands/CreativeCommonsSampling
```

```text
include('fontawesome-6/Brands/CreativeCommonsSampling')
```



| Illustration | CreativeCommonsSampling |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Brands/CreativeCommonsSampling.png) | ![illustration for CreativeCommonsSampling](../../fontawesome-6/Brands/CreativeCommonsSampling.Local.png) |




## CreativeCommonsSampling

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element CreativeCommonsSampling
include('fontawesome-6/Brands/CreativeCommonsSampling')

' renders the element
CreativeCommonsSampling('CreativeCommonsSampling', 'Creative Commons Sampling', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element CreativeCommonsSampling
include('fontawesome-6/Brands/CreativeCommonsSampling')

' renders the element
CreativeCommonsSampling('CreativeCommonsSampling', 'Creative Commons Sampling', 'an optional tech label', 'an optional description')
@enduml
```
